@@ -278,6 +278,14 @@ _build_constraint_string (PolKitAuthorization *auth, PolKitAuthorizationConstrai
         case POLKIT_AUTHORIZATION_CONSTRAINT_TYPE_REQUIRE_ACTIVE:
                 g_string_append (str, _("Must be in active session"));
                 break;
+        case POLKIT_AUTHORIZATION_CONSTRAINT_TYPE_REQUIRE_EXE:
+                g_string_append_printf (str, _("Must be program %s"),
+                                        polkit_authorization_constraint_get_exe (authc));
+                break;
+        case POLKIT_AUTHORIZATION_CONSTRAINT_TYPE_REQUIRE_SELINUX_CONTEXT:
+                g_string_append_printf (str, _("Must be SELinux Context %s"),
+                                        polkit_authorization_constraint_get_selinux_context (authc));
+                break;
         default:
                 buf[sizeof (buf) - 1] = '\0';
                 polkit_authorization_constraint_to_string (authc, buf, sizeof (buf) - 1);
@@ -424,30 +432,35 @@ add_authorization (PolKitAuthorizationDB *authdb,
         }
 
         GdkPixbuf *pixbuf;
+        GdkPixbuf *pixbuf_to_use;
         pixbuf = get_face_for_uid (for_uid);
 
         if (is_negative) {
+                pixbuf_to_use = gdk_pixbuf_copy (pixbuf);
 
                 /* turn black and white */
-                gdk_pixbuf_saturate_and_pixelate (pixbuf,
-                                                  pixbuf,
+                gdk_pixbuf_saturate_and_pixelate (pixbuf_to_use,
+                                                  pixbuf_to_use,
                                                   0.0,
                                                   FALSE);
 
                 /* blend the STOP icon on top */
                 gdk_pixbuf_composite (stop_pixbuf,
-                                      pixbuf,
+                                      pixbuf_to_use,
                                       12, 12, 12, 12,
                                       12.0, 12.0, 0.5, 0.5,
                                       GDK_INTERP_BILINEAR,
                                       255);
 
+        } else {
+                pixbuf_to_use = g_object_ref (pixbuf);
         }
+        g_object_unref (pixbuf);
 
         GtkTreeIter iter;
         gtk_list_store_append (authlist_store, &iter);
         gtk_list_store_set (authlist_store, &iter,
-                            EXPLICIT_ICON_COLUMN, pixbuf,
+                            EXPLICIT_ICON_COLUMN, pixbuf_to_use,
                             EXPLICIT_ENTITY_NAME_COLUMN, for_user,
                             EXPLICIT_SCOPE_COLUMN, scope,
                             EXPLICIT_CONSTRAINTS_COLUMN, constraint_string,
@@ -459,7 +472,6 @@ add_authorization (PolKitAuthorizationDB *authdb,
         /* ref the authorization */
         reffed_auths = g_slist_prepend (reffed_auths, polkit_authorization_ref (auth));
 
-        g_object_unref (pixbuf);
         g_free (for_user);
         g_free (scope);
         g_free (how);
@@ -1393,8 +1405,12 @@ update_summary (void)
                                                            48, 
                                                            0, 
                                                            NULL);
-                        gtk_image_set_from_pixbuf (GTK_IMAGE (summary_action_icon), pixbuf);
-                        g_object_unref (pixbuf);
+                        if (pixbuf != NULL) {
+                                gtk_image_set_from_pixbuf (GTK_IMAGE (summary_action_icon), pixbuf);
+                                g_object_unref (pixbuf);
+                        } else {
+                                gtk_image_clear (GTK_IMAGE (summary_action_icon));
+                        }
                 } else {
                         gtk_image_clear (GTK_IMAGE (summary_action_icon));
                 }
@@ -2329,6 +2345,10 @@ main (int argc, char **argv)
                                                        (GBoxedCopyFunc) polkit_policy_file_entry_ref,
                                                        (GBoxedFreeFunc) polkit_policy_file_entry_unref);
 
+        bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+        bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+        textdomain (GETTEXT_PACKAGE);
+
         loop = g_main_loop_new (NULL, FALSE);
 
         pkgc = polkit_gnome_context_get (NULL);
